# Unable to install plugin because of proxy

**URL:** <https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371>\
**Category:** Elasticsearch\
**Created:** [November 12, 2013, 10:51pm UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371 "2013-11-12T22:51:15Z")\
**Posts on this page:** 11\
**Page:** 1

<div class="post-metadata">

**Author:** ![Amit\_Soni](https://avatars.discourse-cdn.com/v4/letter/a/c0e974/32.png) [@Amit\_Soni](https://discuss.elastic.co/u/Amit_Soni)\
**Post date:** [November 12, 2013, 10:51pm UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/1 "2013-11-12T22:51:15Z")

</div>

Hi all - My servers use a proxy for outbound internet traffic and hence I  
have exported http\_proxy.

I am able to curl to external websites (http as well as https) but I am  
unable to install the head plugin.

_bin/plugin -install mobz/elasticsearch-head-\> Installing  
mobz/elasticsearch-head...Trying  
 [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
 [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
to install mobz/elasticsearch-head, reason: failed to download out of all  
possible locations..., use -verbose to get detailed information_

any comments how I can let the plugin install tool use proxy setting?

-Amit.

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![jprante](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/jprante/32/44941_2.png) [@jprante](https://discuss.elastic.co/u/jprante)\
**Post date:** [November 12, 2013, 11:15pm UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/2 "2013-11-12T23:15:20Z")

</div>

Does

bin/plugin -install mobz/elasticsearch-head -url  
[http://github.com/mobz/elasticsearch-head/archive/master.zip](http://github.com/mobz/elasticsearch-head/archive/master.zip)

work?

Jörg

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![search](https://avatars.discourse-cdn.com/v4/letter/s/dfb087/32.png) [@search](https://discuss.elastic.co/u/search)\
**Post date:** [November 13, 2013, 12:41am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/3 "2013-11-13T00:41:00Z")

</div>

You can download the zip file and run the following:

bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head

---

<div class="post-metadata">

**Author:** ![search](https://avatars.discourse-cdn.com/v4/letter/s/dfb087/32.png) [@search](https://discuss.elastic.co/u/search)\
**Post date:** [November 13, 2013, 12:50am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/4 "2013-11-13T00:50:12Z")

</div>

You can download the zip file and run the following:

bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head

On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:

> Hi all - My servers use a proxy for outbound internet traffic and hence I  
> have exported http\_proxy.
> 
> I am able to curl to external websites (http as well as https) but I am  
> unable to install the head plugin.
> 
> _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> mobz/elasticsearch-head...Trying  
> [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> to install mobz/elasticsearch-head, reason: failed to download out of all  
> possible locations..., use -verbose to get detailed information_
> 
> any comments how I can let the plugin install tool use proxy setting?
> 
> -Amit.

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Amit\_Soni](https://avatars.discourse-cdn.com/v4/letter/a/c0e974/32.png) [@Amit\_Soni](https://discuss.elastic.co/u/Amit_Soni)\
**Post date:** [November 13, 2013, 2:00am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/5 "2013-11-13T02:00:48Z")

</div>

Jörg - Specifying the url somehow does not work. However based on the  
second suggestion, I was able to first download the zip and then specify  
the url of local file which worked fine.

just curious why would specifying an internet/http url not work and  
specifying file:/// url works?

-Amit.

On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com) wrote:

> You can download the zip file and run the following:
> 
> bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> 
> On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:
> 
> > Hi all - My servers use a proxy for outbound internet traffic and hence I  
> > have exported http\_proxy.
> > 
> > I am able to curl to external websites (http as well as https) but I am  
> > unable to install the head plugin.
> > 
> > _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> > mobz/elasticsearch-head...Trying  
> > [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> > [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> > to install mobz/elasticsearch-head, reason: failed to download out of all  
> > possible locations..., use -verbose to get detailed information_
> > 
> > any comments how I can let the plugin install tool use proxy setting?
> > 
> > -Amit.
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![warkolm](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/warkolm/32/39224_2.png) [@warkolm](https://discuss.elastic.co/u/warkolm)\
**Post date:** [November 13, 2013, 2:29am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/6 "2013-11-13T02:29:25Z")

</div>

Because file is using a local file (ie on disk) and not over the network.

Regards,  
Mark Walkom

Infrastructure Engineer  
Campaign Monitor  
email: [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)  
web: [www.campaignmonitor.com](http://www.campaignmonitor.com)

On 13 November 2013 13:00, Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) wrote:

> Jörg - Specifying the url somehow does not work. However based on the  
> second suggestion, I was able to first download the zip and then specify  
> the url of local file which worked fine.
> 
> just curious why would specifying an internet/http url not work and  
> specifying file:/// url works?
> 
> -Amit.
> 
> On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com) wrote:
> 
> > You can download the zip file and run the following:
> > 
> > bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> > 
> > On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:
> > 
> > > Hi all - My servers use a proxy for outbound internet traffic and hence  
> > > I have exported http\_proxy.
> > > 
> > > I am able to curl to external websites (http as well as https) but I am  
> > > unable to install the head plugin.
> > > 
> > > _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> > > mobz/elasticsearch-head...Trying  
> > > [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> > > [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> > > to install mobz/elasticsearch-head, reason: failed to download out of all  
> > > possible locations..., use -verbose to get detailed information_
> > > 
> > > any comments how I can let the plugin install tool use proxy setting?
> > > 
> > > -Amit.
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Amit\_Soni](https://avatars.discourse-cdn.com/v4/letter/a/c0e974/32.png) [@Amit\_Soni](https://discuss.elastic.co/u/Amit_Soni)\
**Post date:** [November 13, 2013, 2:38am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/7 "2013-11-13T02:38:50Z")

</div>

actually my question is more around why the "wget" of file works but a  
direct install of plugin (which internally might be using something  
equivalent of wget) does not work.  
We can surely download plugins one by one and then install it the way as  
mentioned above (_bin/plugin -u file:///your/zip/file/path -i  
mobz/elasticsearch-head_) but understanding the problem would help.

-Amit.

On Tue, Nov 12, 2013 at 6:29 PM, Mark Walkom [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)wrote:

> Because file is using a local file (ie on disk) and not over the network.
> 
> Regards,  
> Mark Walkom
> 
> Infrastructure Engineer  
> Campaign Monitor  
> email: [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)  
> web: [www.campaignmonitor.com](http://www.campaignmonitor.com)
> 
> On 13 November 2013 13:00, Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) wrote:
> 
> > Jörg - Specifying the url somehow does not work. However based on the  
> > second suggestion, I was able to first download the zip and then specify  
> > the url of local file which worked fine.
> > 
> > just curious why would specifying an internet/http url not work and  
> > specifying file:/// url works?
> > 
> > -Amit.
> > 
> > On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com) wrote:
> > 
> > > You can download the zip file and run the following:
> > > 
> > > bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> > > 
> > > On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:
> > > 
> > > > Hi all - My servers use a proxy for outbound internet traffic and hence  
> > > > I have exported http\_proxy.
> > > > 
> > > > I am able to curl to external websites (http as well as https) but I  
> > > > am unable to install the head plugin.
> > > > 
> > > > _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> > > > mobz/elasticsearch-head...Trying  
> > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> > > > to install mobz/elasticsearch-head, reason: failed to download out of all  
> > > > possible locations..., use -verbose to get detailed information_
> > > > 
> > > > any comments how I can let the plugin install tool use proxy setting?
> > > > 
> > > > -Amit.
> > > 
> > > --  
> > > You received this message because you are subscribed to the Google  
> > > Groups "elasticsearch" group.  
> > > To unsubscribe from this group and stop receiving emails from it, send  
> > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![johtani](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/johtani/32/44956_2.png) [@johtani](https://discuss.elastic.co/u/johtani)\
**Post date:** [November 13, 2013, 2:44am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/8 "2013-11-13T02:44:12Z")

</div>

Hi Amit,

You try the following command that specified proxy host and port number.

./bin/plugin -DproxyPort=\*port\_number \*-DproxyHost=\*hostname \*-install  
mobz/elasticsearch-head

2013/11/13 Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com)

> actually my question is more around why the "wget" of file works but a  
> direct install of plugin (which internally might be using something  
> equivalent of wget) does not work.  
> We can surely download plugins one by one and then install it the way as  
> mentioned above (_bin/plugin -u file:///your/zip/file/path -i  
> mobz/elasticsearch-head_) but understanding the problem would help.
> 
> -Amit.
> 
> On Tue, Nov 12, 2013 at 6:29 PM, Mark Walkom [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)wrote:
> 
> > Because file is using a local file (ie on disk) and not over the network.
> > 
> > Regards,  
> > Mark Walkom
> > 
> > Infrastructure Engineer  
> > Campaign Monitor  
> > email: [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)  
> > web: [www.campaignmonitor.com](http://www.campaignmonitor.com)
> > 
> > On 13 November 2013 13:00, Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) wrote:
> > 
> > > Jörg - Specifying the url somehow does not work. However based on the  
> > > second suggestion, I was able to first download the zip and then specify  
> > > the url of local file which worked fine.
> > > 
> > > just curious why would specifying an internet/http url not work and  
> > > specifying file:/// url works?
> > > 
> > > -Amit.
> > > 
> > > On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com)wrote:
> > > 
> > > > You can download the zip file and run the following:
> > > > 
> > > > bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> > > > 
> > > > On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:
> > > > 
> > > > > Hi all - My servers use a proxy for outbound internet traffic and  
> > > > > hence I have exported http\_proxy.
> > > > > 
> > > > > I am able to curl to external websites (http as well as https) but I  
> > > > > am unable to install the head plugin.
> > > > > 
> > > > > _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> > > > > mobz/elasticsearch-head...Trying  
> > > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> > > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> > > > > to install mobz/elasticsearch-head, reason: failed to download out of all  
> > > > > possible locations..., use -verbose to get detailed information_
> > > > > 
> > > > > any comments how I can let the plugin install tool use proxy setting?
> > > > > 
> > > > > -Amit.
> > > > 
> > > > --  
> > > > You received this message because you are subscribed to the Google  
> > > > Groups "elasticsearch" group.  
> > > > To unsubscribe from this group and stop receiving emails from it, send  
> > > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > > 
> > > --  
> > > You received this message because you are subscribed to the Google  
> > > Groups "elasticsearch" group.  
> > > To unsubscribe from this group and stop receiving emails from it, send  
> > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

## --

Jun Ohtani  
blog : [http://blog.johtani.info](http://blog.johtani.info)

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Amit\_Soni](https://avatars.discourse-cdn.com/v4/letter/a/c0e974/32.png) [@Amit\_Soni](https://discuss.elastic.co/u/Amit_Soni)\
**Post date:** [November 13, 2013, 3:36am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/9 "2013-11-13T03:36:52Z")

</div>

Great, this works! _Thanks_ much Jun!

I did not know that proxy parameters are supported in the plugin command. I  
kind of assumed that it would pick the proxy settings from the system but  
that does not seem to be the case.

also the usage doesn't talk about proxy:

_Usage: -u, --url [plugin location] : Set exact URL to download  
the plugin from -i, --install [plugin name] : Downloads and  
installs listed plugins [_] -r, --remove [plugin name] : Removes  
listed plugins -l, --list : List installed  
plugins -v, --verbose : Prints verbose messages  
-s, --silent : Run in silent mode -h,  
--help : Prints this help message\*

However I am good now, thanks everyone 🙂

-Amit.

On Tue, Nov 12, 2013 at 6:44 PM, Jun Ohtani [johtani@gmail.com](mailto:johtani@gmail.com) wrote:

> Hi Amit,
> 
> You try the following command that specified proxy host and port number.
> 
> ./bin/plugin -DproxyPort=\*port\_number \*-DproxyHost=\*hostname \*-install  
> mobz/elasticsearch-head
> 
> 2013/11/13 Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com)
> 
> > actually my question is more around why the "wget" of file works but a  
> > direct install of plugin (which internally might be using something  
> > equivalent of wget) does not work.  
> > We can surely download plugins one by one and then install it the way as  
> > mentioned above (_bin/plugin -u file:///your/zip/file/path -i  
> > mobz/elasticsearch-head_) but understanding the problem would help.
> > 
> > -Amit.
> > 
> > On Tue, Nov 12, 2013 at 6:29 PM, Mark Walkom [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)wrote:
> > 
> > > Because file is using a local file (ie on disk) and not over the network.
> > > 
> > > Regards,  
> > > Mark Walkom
> > > 
> > > Infrastructure Engineer  
> > > Campaign Monitor  
> > > email: [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)  
> > > web: [www.campaignmonitor.com](http://www.campaignmonitor.com)
> > > 
> > > On 13 November 2013 13:00, Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) wrote:
> > > 
> > > > Jörg - Specifying the url somehow does not work. However based on the  
> > > > second suggestion, I was able to first download the zip and then specify  
> > > > the url of local file which worked fine.
> > > > 
> > > > just curious why would specifying an internet/http url not work and  
> > > > specifying file:/// url works?
> > > > 
> > > > -Amit.
> > > > 
> > > > On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com)wrote:
> > > > 
> > > > > You can download the zip file and run the following:
> > > > > 
> > > > > bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> > > > > 
> > > > > On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:
> > > > > 
> > > > > > Hi all - My servers use a proxy for outbound internet traffic and  
> > > > > > hence I have exported http\_proxy.
> > > > > > 
> > > > > > I am able to curl to external websites (http as well as https) but I  
> > > > > > am unable to install the head plugin.
> > > > > > 
> > > > > > _bin/plugin -install mobz/elasticsearch-head-\> Installing  
> > > > > > mobz/elasticsearch-head...Trying  
> > > > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip).  
> > > > > > [https://github.com/mobz/elasticsearch-head/archive/master.zip.](https://github.com/mobz/elasticsearch-head/archive/master.zip.).. Failed  
> > > > > > to install mobz/elasticsearch-head, reason: failed to download out of all  
> > > > > > possible locations..., use -verbose to get detailed information_
> > > > > > 
> > > > > > any comments how I can let the plugin install tool use proxy setting?
> > > > > > 
> > > > > > -Amit.
> > > > > 
> > > > > --  
> > > > > You received this message because you are subscribed to the Google  
> > > > > Groups "elasticsearch" group.  
> > > > > To unsubscribe from this group and stop receiving emails from it, send  
> > > > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > > > 
> > > > --  
> > > > You received this message because you are subscribed to the Google  
> > > > Groups "elasticsearch" group.  
> > > > To unsubscribe from this group and stop receiving emails from it, send  
> > > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > > 
> > > --  
> > > You received this message because you are subscribed to the Google  
> > > Groups "elasticsearch" group.  
> > > To unsubscribe from this group and stop receiving emails from it, send  
> > > an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> ## --
> 
> Jun Ohtani  
> blog : [http://blog.johtani.info](http://blog.johtani.info)
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![johtani](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/johtani/32/44956_2.png) [@johtani](https://discuss.elastic.co/u/johtani)\
**Post date:** [November 13, 2013, 4:22am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/10 "2013-11-13T04:22:02Z")

</div>

Hi,

I read the code org.elasticsearch.plugin.PluginManager.java.  
PluginManager use java.net.URL.openConnection() to download plugins.  
-DproxyPort and -DproxyHost parameter is Java Networking system properties.  
Using http.proxyPort and http.proxyHost instead of proxyHost and proxyPort is recommended currently, see the following reference link.

But, I don’t try to use “http.\*” system properties because I don’t have proxy environment. Sorry.

Reference : [Networking Properties](http://java.sun.com/javase/6/docs/technotes/guides/net/properties.html)

* * *

Jun Ohtani  
[johtani@gmail.com](mailto:johtani@gmail.com)  
blog : [http://blog.johtani.info](http://blog.johtani.info)  
twitter : [http://twitter.com/johtani](http://twitter.com/johtani)

2013/11/13 12:36、Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) のメール：

> Great, this works! Thanks much Jun!
> 
> I did not know that proxy parameters are supported in the plugin command. I kind of assumed that it would pick the proxy settings from the system but that does not seem to be the case.
> 
> also the usage doesn't talk about proxy:
> 
> Usage:  
> -u, --url [plugin location] : Set exact URL to download the plugin from  
> -i, --install [plugin name] : Downloads and installs listed plugins [\*]  
> -r, --remove [plugin name] : Removes listed plugins  
> -l, --list : List installed plugins  
> -v, --verbose : Prints verbose messages  
> -s, --silent : Run in silent mode  
> -h, --help : Prints this help message
> 
> However I am good now, thanks everyone 🙂
> 
> -Amit.
> 
> On Tue, Nov 12, 2013 at 6:44 PM, Jun Ohtani [johtani@gmail.com](mailto:johtani@gmail.com) wrote:  
> Hi Amit,
> 
> You try the following command that specified proxy host and port number.
> 
> ./bin/plugin -DproxyPort=port\_number -DproxyHost=hostname -install mobz/elasticsearch-head
> 
> 2013/11/13 Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com)  
> actually my question is more around why the "wget" of file works but a direct install of plugin (which internally might be using something equivalent of wget) does not work.  
> We can surely download plugins one by one and then install it the way as mentioned above (bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head) but understanding the problem would help.
> 
> -Amit.
> 
> On Tue, Nov 12, 2013 at 6:29 PM, Mark Walkom [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com) wrote:  
> Because file is using a local file (ie on disk) and not over the network.
> 
> Regards,  
> Mark Walkom
> 
> Infrastructure Engineer  
> Campaign Monitor  
> email: [markw@campaignmonitor.com](mailto:markw@campaignmonitor.com)  
> web: [www.campaignmonitor.com](http://www.campaignmonitor.com)
> 
> On 13 November 2013 13:00, Amit Soni [amitsoni29@gmail.com](mailto:amitsoni29@gmail.com) wrote:  
> Jörg - Specifying the url somehow does not work. However based on the second suggestion, I was able to first download the zip and then specify the url of local file which worked fine.
> 
> just curious why would specifying an internet/http url not work and specifying file:/// url works?
> 
> -Amit.
> 
> On Tue, Nov 12, 2013 at 4:50 PM, Search User [feedworks@gmail.com](mailto:feedworks@gmail.com) wrote:  
> You can download the zip file and run the following:
> 
> bin/plugin -u file:///your/zip/file/path -i mobz/elasticsearch-head
> 
> On Tuesday, November 12, 2013 5:51:15 PM UTC-5, amit.soni wrote:  
> Hi all - My servers use a proxy for outbound internet traffic and hence I have exported http\_proxy.
> 
> I am able to curl to external websites (http as well as https) but I am unable to install the head plugin.
> 
> bin/plugin -install mobz/elasticsearch-head  
> -\> Installing mobz/elasticsearch-head...  
> Trying [https://github.com/mobz/elasticsearch-head/archive/master.zip](https://github.com/mobz/elasticsearch-head/archive/master.zip)...  
> Failed to install mobz/elasticsearch-head, reason: failed to download out of all possible locations..., use -verbose to get detailed information
> 
> any comments how I can let the plugin install tool use proxy setting?
> 
> -Amit.
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> ## --
> 
> Jun Ohtani  
> blog : [http://blog.johtani.info](http://blog.johtani.info)
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> 
> --  
> You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![system](https://us1.discourse-cdn.com/elastic/original/3X/1/a/1ac57faf039f6b580b3f104ef42a2a89e41014de.png) [@system](https://discuss.elastic.co/u/system)\
**Post date:** [July 6, 2017, 2:07am UTC](https://discuss.elastic.co/t/unable-to-install-plugin-because-of-proxy/14371/11 "2017-07-06T02:07:37Z")

</div>


